<?php

namespace Schaffen\ProductionOrder\ProductionOrder\Models;

use Illuminate\Database\Eloquent\Model;
use Schaffen\WarehouseInventory\WarehouseInventory\Models\WarehouseInventory;

class Status extends Model
{
    protected $table = "ordem_producao.status";
    protected $fillable = [
        "st_descricao",
        "st_controla_estoque",
        "st_fk_loe_codigo_origem",
        "st_fk_loe_codigo_destino",
        "st_user_insert",
        "st_date_insert",
        "st_user_update",
        "st_date_update",
        "st_user_delete",
        "st_date_delete",
    ];
    
    protected $primaryKey = "st_codigo";
    
    const UPDATED_AT = 'created_at';
    const CREATED_AT = 'updated_at';
    const DELETED_AT = 'deleted_at';

    public function warehouse_inventory_origin() {
        return $this->belongsTo(WarehouseInventory::class, 'st_fk_loe_codigo_origem', 'loe_codigo');
    }

    public function warehouse_inventory_destiny() {
        return $this->belongsTo(WarehouseInventory::class, 'st_fk_loe_codigo_destino', 'loe_codigo');
    }

    public function editable() {
        return $this->attributes['st_codigo'] == 1;
    }

    public function isFinal() {
        return $this->attributes['st_codigo'] == 3;
    }

}
